pygeodesy.props.property_RO

Package pygeodesy :: Module props :: Class property_RO |
[frames] | no frames]

# Class property_RO

    object --+
             |
      property --+
                 |
     _PropertyBase --+
                     |
                    property_RO

Known Subclasses:
  - named._LazyNamedEnumItem

Instance Methods
    property attribute
__init__(self, method, doc='') New immutable, standard `property` to be used as `decorator`. |
Inherited from `_PropertyBase`: `deleter`, `getter`, `setter` Inherited from `property`: `__delete__`, `__get__`, `__getattribute__`, `__new__`, `__set__` Inherited from `object`: `__delattr__`, `__format__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `property`: `fdel`, `fget`, `fset` Inherited from `object`: `__class__`

Method Details

### __init__ (self, method, doc='') (Constructor) |
New immutable, standard `property` to be used as `decorator`. Arguments: `method` - The callable being decorated as `property`'s `getter`. `doc` - Optional property documentation (`str`). Returns:
    property attribute
Overrides: object.__init__ Note: Like standard Python `property` without a setter, but with a more descriptive error message when set. See Also: Property_RO.